@@ -416,9 +416,13 @@ class _Date(_Text):
         tz = tz or self.tz
         if isinstance(tz, basestring):
             tz = timezone(tz)
+        value = self.python_value
+        if isinstance(value, date) and not isinstance(value, datetime):
+            now = datetime.utcnow()
+            value = datetime(value.year, value.month, value.day,
+                now.hour, now.minute, now.second)
         try:
-            return format_datetime(self.python_value, format=self.format,
-                tzinfo=tz, locale=locale)
+            return format_datetime(value, format=self.format, tzinfo=tz, locale=locale)
         except Exception:
             # raise
             return u''
